@@ -10,7 +10,7 @@ class Interpolator:
     def __init__(self, points=100):
         self.points = points
 
-    def approximate(self, x, y):
+    def interpolate(self, x, y):
         pass
 
 
@@ -28,7 +28,17 @@ class Quadratic(Interpolator):
         """
         return linspace(start, end, self.points)
 
-    def approximate(self, x, y):
+    def interpolate(self, x, y):
+        """
+        Производит квадратическую интерполяцию, подробнее в `документации numpy`_
+
+        .. _`документации numpy`: https://docs.scipy.org/doc/scipy/reference/generated/scipy.interpolate.interp1d.html
+
+        :param x: координаты по оси x
+        :param y: координаты по оси y
+
+        :return: набор координат по оси x и набор координат по оси y после интерполяции
+        """
         points = interp1d(x, y, kind='quadratic')
         x = linspace(min(x), max(x), self.points)
         y = points(x)
